ProtoBaseApiClient class

A client for interacting with the ProtoBase API.

Constructors

ProtoBaseApiClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAndRefreshToken() Future<void>
Checks the validity of the access token and refreshes it if necessary.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signinWithEmail(String username, String password, String email, String token, BuildContext context, Widget targetPage) Future<void>
Signs in a user with the provided username, password, email, and token.
signinWithUsername(String username, String password, String token, BuildContext context, Widget targetPage) Future<void>
Signs in a user with the provided username, password, and token.
signOut(BuildContext context, Widget targetPage) Future<void>
Signs out the user by clearing the stored tokens and navigating to the targetPage.
signupWithEmail(String username, String password, String email, String token, BuildContext context, Widget targetPage) Future<void>
Signs up a user with the provided username, password, email, and token.
signupWithUsername(String username, String password, String token, BuildContext context, Widget targetPage) Future<void>
Signs up a user with the provided username, password, and token.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited