ProtoBaseDatabaseClient class

A client for interacting with the ProtoBase API for database operations.

Constructors

ProtoBaseDatabaseClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createTable(String apiToken, String username, String projectName, String tableName, List<String> columns, List<String> columnTypes) Future<Map<String, dynamic>>
Creates a table in the specified project.
deleteData(String apiToken, String username, String projectName, String table, String condition) Future<Map<String, dynamic>>
Deletes data from the specified table.
insertData(String apiToken, String username, String projectName, String table, Map<String, dynamic> data) Future<Map<String, dynamic>>
Inserts data into the specified table.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readData(String apiToken, String username, String projectName, String table) Future<Map<String, dynamic>>
Reads data from the specified table.
toString() String
A string representation of this object.
inherited
updateData(String apiToken, String username, String projectName, String table, String whereClause, Map<String, dynamic> updateData) Future<Map<String, dynamic>>
Updates data in the specified table.

Operators

operator ==(Object other) bool
The equality operator.
inherited